=============================
``psyclone.psyir.nodes.node``
=============================

.. automodule:: psyclone.psyir.nodes.node

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.node


Functions
=========

- :py:func:`colored`:
  Colorize text.


.. autofunction:: colored


Classes
=======

- :py:class:`ChildrenList`:
  Customized list to keep track of the children nodes. It is initialised with

- :py:class:`Node`:
  Base class for a PSyIR node.


.. autoclass:: ChildrenList
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ChildrenList
      :parts: 1

.. autoclass:: Node
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Node
      :parts: 1
